/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension;

import org.fortiss.tooling.kernel.extension.data.ILogMessageContext;
import org.fortiss.tooling.kernel.extension.data.LogMessage;
import org.fortiss.tooling.kernel.service.base.IObjectAware;

/**
 * The UIMessageService provides registration and access to MessageHandlers that are used to display
 * messages emitted from model plugins to the user. A MessageHandler knows how to present the given
 * Message to the user, e.g., the layout or dialog style.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 6CF449AC3BD02DA1CDF5DF3DCE59652B
 */
public interface LogMessageHandler extends IObjectAware<LogMessage> {
	/**
	 * Returns whether {@code this} handler accepts the given {@link LogMessage} from the given
	 * {@link ILogMessageContext}.
	 * 
	 * @param message
	 *            {@link LogMessage} to be processed.
	 * @param context
	 *            The context from which the {@link LogMessage} has been emitted.
	 * @return boolean whether the {@link LogMessage} would be processed.
	 */
	boolean acceptMessage(LogMessage message, ILogMessageContext context);

	/** Processes the {@link LogMessage} by the handler. */
	void showMessage(LogMessage message);
}
