/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import org.fortiss.tooling.kernel.extension.LogMessageHandler;
import org.fortiss.tooling.kernel.extension.data.ILogMessageContext;
import org.fortiss.tooling.kernel.extension.data.LogMessage;
import org.fortiss.tooling.kernel.internal.LoggingService;

/**
 * The logging service allows methods to emit {@link LogMessage}s that are processed by
 * {@link LogMessageHandler}s. The service is implemented in a broadcast manner such that each
 * handler is activated that accepts the emitted {@link LogMessage} with the given
 * {@link ILogMessageContext}.
 * 
 * One very useful use case is the possibility to emit messages from a non-UI plugin which are
 * displayed by handler registered in a UI plugin.
 * Another use case is the easy implementation of a logger that registers as a handler.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 256DEBB479F0B05DFA2C2329DDCFE276
 */
public interface ILoggingService {
	/** Returns the singleton instance of the service. */
	public static final ILoggingService INSTANCE = new LoggingService();

	/**
	 * Triggers the processing method of the given {@link LogMessage} for all
	 * {@link LogMessageHandler}s that accept the {@link LogMessage} from the given
	 * {@link ILogMessageContext}.
	 */
	void processMessage(LogMessage message, ILogMessageContext context);
}
